import logging
import time
from threading import *
from AudioSource import *
import baco
from PlaylistParser import *


class HTTPAudioSource(AudioSource):
    def __init__(self, sourceId, name, volume, parameters, audioDev):
        AudioSource.__init__(self,sourceId, name, volume, parameters, audioDev)
        
        self.audioDevice = AudioSource.getAudioDev(self)
        self.url = AudioSource.getParameter(self,"url")
        self.url = self.url.rstrip()

        self.lock = Lock()

        self.monitoringThread = None
        self.isMonitoring = False
        
        self.logger     = logging.getLogger('ipspeaker')
        self.externalCallback = None

        # if http[s]://user:pass@url format does not check if is a playlist
        match = re.search("^http[s]?:\/\/(.*:.*)@", self.url) 
        if not match:
            playlist = PlaylistParser(self.url)
            url_stream = playlist.getStream()   #if url is a playlist get stream from it
            if playlist.getStream() is not None:
                self.url = url_stream

        self.player = baco.SimplePlayer(self.url, self.audioDevice, 44100, baco.FULLBUFFER)
        self.player.setInputFifoDuration(0)
        self.player.setOutputFifoDuration(7000)
        self.player.setReadyThreshold(5000)
        self.player.setCallback(self.checkStateCallback)
        self.setEqualizer()

    def connect(self):
        with self.lock:
            if not self.player.isConnected():
                if self.player.getState() == baco.PlayerState.DRAINING:
                    self.logger.info(f"Player entered draining state ... will stop player")
                    self.player.disconnect()
                else:
                    self.logger.info(f"Connecting source id={self.id}, name={self.name}")
                    self.player.connectSource()

    def disconnect(self):
        with self.lock:
            if self.player.isConnected():
                self.logger.info(f"Disconnecting source id={self.id}, name={self.name}")
                self.player.disconnect()

    def shutdown(self):
        self.logger.info("Shutdown HTTP audio source")
        self.disconnect()

    def playAudio(self):
        with self.lock:
            self.logger.info(f"Playing source id={self.id}, name={self.name}")
            self.player.connectAudio()

    def stopAudio(self):
        with self.lock:
            self.logger.info(f"Muting source id={self.id}, name={self.name}")
            self.player.disconnectAudio()

    def reportStatus(self):
        sourceDict = {}
        sourceDict["id"] = self.id
        return sourceDict

    def setEqualizer(self):
        with self.lock:
            AudioSource.setEqualizer(self, self.player)

    def setEqualizerParameter(self, config):
        with self.lock:
            return AudioSource.setEqualizerParameter(self, self.player, config)

    def enableEqualizer(self, enable):
        with self.lock:
            AudioSource.enableEqualizer(self, self.player, enable)

    def setCallback(self, callback):
        self.externalCallback = callback

    def checkStateCallback(self, alive):
        self.logger.debug(f"Source {self.id}, alive {alive}")
        if self.externalCallback is not None:
            self.externalCallback(self, alive)
