import json
import logging
import os

log = logging.getLogger('flask-backend')

from barix import HTTPRequestsAPI
from barix.web.utils import readFromJSONFile

from ipformer import getIPFormerSources

SCHEDULER_CONFIG_FILE = "/mnt/data/config/scheduler.json"

def getSchedulerConfig():
    scheduler_config = {}
    try:
        if os.path.isfile(SCHEDULER_CONFIG_FILE):
            scheduler_config = readFromJSONFile(SCHEDULER_CONFIG_FILE)
    except Exception as e:
        log.error(e)
        raise e
    else:
        return scheduler_config

def setSchedulerConfig(scheduler_config):
    try:
        with open(SCHEDULER_CONFIG_FILE, 'w') as outfile:
            json.dump(scheduler_config, outfile)
    except Exception as e:
        log.error(e)
        raise e

def updateSchedulerPlaylists(playlistsDict):
    try:
        schedulerConfig = getSchedulerConfig()
        if 'playlists' in schedulerConfig.keys():
            schedulerConfig['playlists'] = [x for x in schedulerConfig['playlists'] if x['id'] in playlistsDict.keys()]
            setSchedulerConfig(schedulerConfig)
            restartScheduler()
    except Exception as e:
        log.error(e)
        raise e

def restartScheduler():
    try:
        schedulerSourceID = None
        sourcesList = getIPFormerSources()
        for sourceID in sourcesList:
            if "type" in sourcesList[sourceID].keys() and sourcesList[sourceID]["type"] == "scheduler" and sourcesList[sourceID]["enabled"]:
                schedulerSourceID = sourceID.replace('source', '')
                break
        if schedulerSourceID is not None:
            url = 'http://127.0.0.1:50500/api/scheduler/set'
            try:
                HTTPRequestsAPI.put(url, {"sourceId": int(schedulerSourceID)})
            except Exception as e:
                log.error(
                    "Error sending PUT request {} to {} : {}".format({"sourceId": int(schedulerSourceID)}, url, e))
                raise e
    except Exception as e:
        log.error(e)
        raise e

