import json
import logging

from flask import Blueprint, request, Response

from barix.web.auth import login_required
from barix.web.uci import getAllConfigs, getValueOfUci

bp = Blueprint('uci_API', __name__)

log = logging.getLogger('flask-backend')

@bp.route('/api/rest/v1/ucis', methods=['GET'])
@login_required
def getuci():
    try:
        uciValues = {}
        uciList = request.args

        if uciList == {}:
            log.info("Request list is empty, getting all UCIs")
            uciList = getAllConfigs()

        log.info("Getting value of ucis: {}".format(uciList))

        for uciPath in uciList:
            path_params = uciPath.split('.')
            result = getValueOfUci(path_params[0], path_params[1], path_params[2])
            uciValues[uciPath] = result
        log.info("Returning uci values: {}".format(uciValues))
    except Exception as e:
        log.error(e)
        return Response(status=500)
    else:
        return Response(json.dumps(uciValues), status=200)