#!/usr/bin/python3

import subprocess
import signal
import time
import os
import sys
import syslog
import alsaaudio

import flexa_uci
from barix.io import leds
from barix.licensing import *
from GenericRestAPI import *

def ipac_signal_handler(sig, frame):
    global stopRunning
    print("IPAC signal handler")
    stopRunning = True

def getHwType():
    p = subprocess.Popen(["/usr/bin/qiba-spi-get-production-info.sh", "-w"], stdout=subprocess.PIPE, shell=False)
    return int(p.communicate()[0]) 

def setMainVolume():
    vol = flexa_uci.uci_get('application.audio.volume')
    alsaaudio.Mixer("BARIX_MAIN").setvolume(int(vol))

def checkIpacLicense():
    found, _ = findLicense("core-image-barix-ipspeaker")
    if not found:
        found, _ = findLicense("core-image-barix-ussi-ipspeaker")
        if not found:
            found, _ = findLicense("barix-development-platform")

    if not found:
        syslog.syslog("required license is missing")
        sys.exit(1)

# --------------------------------------------------------------------------------------------------
print("""
===========================
IP Audio Client Starting...
(c) 2020 BARIX AG 
===========================
""")

syslog.openlog("IPAC")

appPath = os.path.dirname(os.path.realpath(__file__))

checkIpacLicense()

syslog.syslog("IP Audio Client Starting ...")

setMainVolume()

hwType = getHwType()

temp_proc = None
overTempCheck = False
if hwType == 69 or hwType == 75: #only MPA400 devices
    temp_proc = subprocess.Popen(["/usr/bin/temp-sensor-monitor.sh"], shell=False)
    overTempCheck = True

mode = flexa_uci.uci_get('application.main_config.mode')
if mode == '':
    mode = 'ipspeaker'
    flexa_uci.uci_set('application.main_config.mode', 'ipspeaker')
    flexa_uci.uci_commit('application')

if mode == 'aes67':
    proc = subprocess.Popen(["/usr/bin/python3", f"{appPath}/run_aes67.py", str(hwType)], shell=False)
    syslog.syslog("Running AES67 Mode")
else:
    proc = subprocess.Popen(["/usr/bin/python3", f"{appPath}/run_ipspeaker.py", str(hwType)], shell=False)
    syslog.syslog("Running IPSpeaker Mode")

signal.signal(signal.SIGINT, ipac_signal_handler)
signal.signal(signal.SIGTERM, ipac_signal_handler)

api = GenericRestAPI(50555)
led = leds.IpamLed("led1")
led.set("green")
led1StatusGreen = True

stopRunning = False

while not stopRunning:
    if hwType == 69 or hwType == 75:  # only MPA400 devices
        try:
            res = api.get('/api/amp/over_temp')
            data = json.dumps(res)
            data = json.loads(data)
            otw = data['over_temp']
            if otw == 1 and led1StatusGreen:
                syslog.syslog("Global overtemperature warning!")
                led.set("yellow",blink=True)
                led1StatusGreen = False
            elif otw == 0 and not led1StatusGreen:
                syslog.syslog("No global overtemperature warning")
                led.set("green")
                led1StatusGreen = True
        except:
            syslog.syslog("Error trying to check MPA400 Amp over temperature")
    time.sleep(1)

if temp_proc is not None:
    temp_proc.terminate()
    temp_proc.wait()
proc.terminate()
proc.wait()