#!/bin/sh
# 
# IP Audio Client Digital Audio amplifier startup configuration
# 
# Supported amplifiers: TAS-2770/TAS-6421
# 
# Board HW_Type
# BARIX_TPA                 66  => TAS-2770
# BARIX_MPA                 69  => TAS-6421 
# BARIX_MPA (HyperSpike)    75  => TAS-6421


#specific TAS-6421 amp settings for MPA
MPA_AMP_CONF_FILE="/etc/barix/mpa_ussi_amp.json"

HW_TYPE=$(/usr/bin/qiba-spi-get-production-info.sh -w)

if [ "$HW_TYPE" = "66" ]; then
    AMP_NAME="tas2770"
    CHIP_ADDR="0x41"
    #check for specific amp level configuration
    AMP_LEVEL_UCI=$(/usr/bin/uci get flexa_ip_former.tpa400.level)
    if [ "$?" = "1" ]; then #create if it does not exist
        AMP_LEVEL_UCI="PoE_Optimized"
        /usr/bin/uci set flexa_ip_former.tpa400=section
        /usr/bin/uci set flexa_ip_former.tpa400.level=$AMP_LEVEL_UCI
    fi

    if [ $AMP_LEVEL_UCI != "PoE_Optimized" ] && [ $AMP_LEVEL_UCI != "Max_Power" ] ; then
        AMP_LEVEL_UCI="PoE_Optimized"
        /usr/bin/uci set flexa_ip_former.tpa400.level=$AMP_LEVEL_UCI
    fi

    Speaker_UCI_Cfg=$(/usr/bin/uci get speaker.speaker.config)
    if [ "${Speaker_UCI_Cfg}" = "" ] || [ "${Speaker_UCI_Cfg}" = "auto" ]; then
        Speaker_UCI_Cfg="4"
        /usr/bin/uci set speaker.speaker.config=$Speaker_UCI_Cfg
    fi 
    #select TPA400 AMP Level based on the specified level and speaker impedance
    if [ $AMP_LEVEL_UCI = "PoE_Optimized" ]; then
        if [ $Speaker_UCI_Cfg = "4" ]; then
            TPA400_AMP_LEVEL="0x07"
        else #8 ohm
            TPA400_AMP_LEVEL="0x0C"
        fi
    else #Max_Power
        if [ $Speaker_UCI_Cfg = "4" ]; then
            TPA400_AMP_LEVEL="0x08"
        else #8 ohm
            TPA400_AMP_LEVEL="0x0C"
        fi
    fi

    /usr/bin/qiba-aplay-loop.sh &
    /usr/bin/digital-audio-amp $AMP_NAME $CHIP_ADDR $TPA400_AMP_LEVEL &
    sleep 5
else
    if [ "$HW_TYPE" = "69" ] || [ "$HW_TYPE" = "75" ]; then
        AMP_NAME="tas6421"
        CHIP_ADDR="0x6a"
        . /usr/bin/poe-detect.sh

        # Get Input Source Supply configuration
        PoE_UCI_Cfg=$(/usr/bin/uci get poe.poe.config)
        PowerSource=${PoE_UCI_Cfg}

        if [ "$PoE_UCI_Cfg" = "" ] || [ "$PoE_UCI_Cfg" = "auto" ]; then
            if [ -f "/tmp/poe-detect" ]; then
                PowerSource=$(cat /tmp/poe-detect | grep "poe.type" | sed -e 's/poe.type\s*=\s*//')
            fi
        fi

        # Get speaker impedance configuration
        Speaker_UCI_Cfg=$(/usr/bin/uci get speaker.speaker.config)
        
        if [ "${Speaker_UCI_Cfg}" = "" ] ; then
            impedance = "auto"
        else
            impedance=${Speaker_UCI_Cfg}
        fi

        /usr/bin/digital-audio-amp $AMP_NAME $CHIP_ADDR 0xCF $PowerSource $impedance $MPA_AMP_CONF_FILE &
	sleep 10 # needed so that sonic-ip starts after detecting impedance
    fi
fi

if [ "$HW_TYPE" != "66" ]; then
    /usr/bin/qiba-aplay-loop.sh &
fi



